@@ -31,7 +31,7 @@
 #define _GLIBCXX_CXX_CONFIG_H 1
 
 // The current version of the C++ library in compressed ISO date format.
-#define __GLIBCXX__ 20150626
+#define __GLIBCXX__ 20160726
 
 // Macros for various attributes.
 //   _GLIBCXX_PURE
@@ -528,7 +528,7 @@ namespace std
 #define _GLIBCXX_HAVE_DLFCN_H 1
 
 /* Define if EBADMSG exists. */
-/* #undef _GLIBCXX_HAVE_EBADMSG */
+#define _GLIBCXX_HAVE_EBADMSG 1
 
 /* Define if ECANCELED exists. */
 #define _GLIBCXX_HAVE_ECANCELED 1
@@ -558,7 +558,7 @@ namespace std
 /* #undef _GLIBCXX_HAVE_ENOSTR */
 
 /* Define if ENOTRECOVERABLE exists. */
-/* #undef _GLIBCXX_HAVE_ENOTRECOVERABLE */
+#define _GLIBCXX_HAVE_ENOTRECOVERABLE 1
 
 /* Define if ENOTSUP exists. */
 #define _GLIBCXX_HAVE_ENOTSUP 1
@@ -567,13 +567,13 @@ namespace std
 #define _GLIBCXX_HAVE_EOVERFLOW 1
 
 /* Define if EOWNERDEAD exists. */
-/* #undef _GLIBCXX_HAVE_EOWNERDEAD */
+#define _GLIBCXX_HAVE_EOWNERDEAD 1
 
 /* Define if EPERM exists. */
 #define _GLIBCXX_HAVE_EPERM 1
 
 /* Define if EPROTO exists. */
-/* #undef _GLIBCXX_HAVE_EPROTO */
+#define _GLIBCXX_HAVE_EPROTO 1
 
 /* Define if ETIME exists. */
 /* #undef _GLIBCXX_HAVE_ETIME */
@@ -1351,6 +1351,11 @@ namespace std
 /* Define to 1 if mutex_timedlock is available. */
 #define _GTHREAD_USE_MUTEX_TIMEDLOCK 1
 
+/* Define if all C++11 overloads are available in <math.h>.  */
+#if __cplusplus >= 201103L
+/* #undef __CORRECT_ISO_CPP11_MATH_H_PROTO */
+#endif
+
 #if defined (_GLIBCXX_HAVE__ACOSF) && ! defined (_GLIBCXX_HAVE_ACOSF)
 # define _GLIBCXX_HAVE_ACOSF 1
 # define acosf _acosf
